AnyTypePrimitive class final

A special primitive type that represents any type.

Inheritance

Constructors

AnyTypePrimitive(String name, String sanitizedName)
Creates a new instance of AnyTypePrimitive given a name and a sanitizedName.
const

Properties

cachedInstantiations → Iterable<InstantiatedInspectEntry>
Returns all instantiations of this entry already created.
no setterinherited
children → Iterable<(String, InspectEntry)>
Returns all children of this entry.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
instantiatingModule → InstantiatedModule
Returns the instantiating module.
no setterinherited
moduleConnections → List<InspectEntryModuleConnection>
Returns all modules to which this entry is connected.
no setterinherited
name → String
Returns the name of this entry in the instantiating module.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry.
finalinherited
source → InspectEntry
Returns the source entry of this instantiation.
no setterinherited
type → InspectEntryType
Returns the type of this entry.
no setterinherited
value → Object?
Returns the value of this entry.
finalinherited

Methods

addModuleConnection(InspectEntryModuleConnection connection) → bool
Connects this entry to a module. Returns true if the connection was successful, false if the connection already existed.
inherited
collectChildren(InspectionCache cache, {required String stdlibPath, required Module parentModule}) → void
Collects all children of this entry during the inspection process.
inherited
debugDump({InspectionCache? cache, bool expandChildren = true}) → Map<String, Object?>
Emits a JSON representation of this entry.
inherited
emit(StringBuffer buffer, {required InspectionCache cache, required AppType appType}) → void
Emits a Dart source for this entry during interface generation.
inherited
emitDoc(StringBuffer buffer) → void
Emits the Python documentation for this entry.
inherited
emitSource(StringBuffer buffer) → void
Emits the Python source for this entry.
inherited
hasModuleConnection(InspectEntryModuleConnection connection) → bool
Helper to check if this entry has a connection to a module.
inherited
instantiate(InstantiatedModule instantiatingModule) → InstantiatedInspectEntry
Creates an instantiation of this entry to the given module. Returns null if this entry cannot be instantiated because it is not connected to this module.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited