ClassInstance class final

Representation of a Python class instance.

Inheritance
  • Object
  • PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>
  • PythonObject
  • PythonClass
  • ClassInstance
Implemented types
Mixed-in types

Constructors

ClassInstance.from(PythonClassInterface<PythonFfiDelegate<Object?>, Object?> classDelegate)
Wraps a Python object in a ClassInstance.

Properties

cachedInstantiations → Iterable<InstantiatedInspectEntry>
Returns all instantiations of this entry already created.
no setterinherited
children → Iterable<(String, InspectEntry)>
Returns all children of this entry.
no setterinherited
definingModule → Object?
Returns the module in which this object is defined.
no setterinherited
finalizer → Finalizer<(PythonFfiDelegate<Object?>, Object?)>
The finalizer for the python object. Gets invoked when the object is no longer accessible to the program.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initializer → Initializer<PythonFfiDelegate<Object?>, Object?>
The initializer for the python object. Gets invoked at the start of the constructor.
finalinherited
inspectModule → inspect
Returns a Dart instance of the Python inspect module.
finalinherited
instantiations → Iterable<InstantiatedInspectEntry>
Returns an instantiation of this entry for each connected module.
no setterinherited
moduleConnections → List<InspectEntryModuleConnection>
Returns all modules to which this entry is connected.
no setterinherited
platform → PythonFfiDelegate<Object?>
Gets the platform that this object is associated with.
no setterinherited
reference → Object?
Gets the reference to the python object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry.
no setterinherited
type → InspectEntryType
Returns the type of this entry.
no setteroverride
value → PythonClassInterface<PythonFfiDelegate<Object?>, Object?>
Returns the value of this entry.
final

Methods

addModuleConnection(InspectEntryModuleConnection connection) → bool
Connects this entry to a module. Returns true if the connection was successful, false if the connection already existed.
inherited
collectChildren(InspectionCache cache, {required String stdlibPath, required Module parentModule}) → void
Collects all children of this entry during the inspection process.
inherited
debugDump({InspectionCache? cache, bool expandChildren = true}) → Map<String, Object?>
Dumps the python object to the console.
inherited
getAttribute<T extends Object?>(String attributeName) → T
Gets the attribute with the given name.
inherited
getAttributeOrNull<T extends Object?>(String attributeName) → T?
Gets the attribute with the given name or null if it does not exist.
inherited
getAttributeRaw<T extends PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>>(String attributeName) → T
Gets the attribute with the given name.
inherited
getFunction(String name) → PythonFunctionInterface<PythonFfiDelegate<Object?>, Object?>
Gets the function with the given name.
inherited
getMethod(String functionName) → PythonFunctionInterface<PythonFfiDelegate<Object?>, Object?>
Gets a method from the class.
inherited
hasAttribute(String attributeName) → bool
Checks if the python object has the given attribute.
inherited
hasModuleConnection(InspectEntryModuleConnection connection) → bool
Helper to check if this entry has a connection to a module.
inherited
instantiate(InstantiatedModule instantiatingModule) → InstantiatedInspectEntry?
Creates an instantiation of this entry to the given module. Returns null if this entry cannot be instantiated because it is not connected to this module.
inherited
noSuchMethod(Invocation invocation) → Object?
Invoked when a nonexistent method or property is accessed.
inherited
setAttribute<T extends Object?>(String attributeName, T value) → void
Sets the attribute with the given name.
inherited
setAttributeRaw<T extends PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>>(String attributeName, T value) → void
Sets the attribute with the given name.
inherited
toDartObject() → Object?
Converts the python object to a Dart object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited