InspectEntry class sealed

Base class for inspect entries.

Implementers

Properties

cachedInstantiations → Iterable<InstantiatedInspectEntry>
Returns all instantiations of this entry already created.
no setter
children → Iterable<(String, InspectEntry)>
Returns all children of this entry.
no setter
hashCode → int
The hash code for this object.
no setterinherited
moduleConnections → List<InspectEntryModuleConnection>
Returns all modules to which this entry is connected.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry.
no setter
type → InspectEntryType
Returns the type of this entry.
no setter
value → Object?
Returns the value of this entry.
no setter

Methods

addModuleConnection(InspectEntryModuleConnection connection) → bool
Connects this entry to a module. Returns true if the connection was successful, false if the connection already existed.
collectChildren(InspectionCache cache, {required String stdlibPath, required Module parentModule}) → void
Collects all children of this entry during the inspection process.
debugDump({InspectionCache? cache, bool expandChildren = true}) → Map<String, Object?>
Emits a JSON representation of this entry.
hasModuleConnection(InspectEntryModuleConnection connection) → bool
Helper to check if this entry has a connection to a module.
instantiate(InstantiatedModule instantiatingModule) → InstantiatedInspectEntry?
Creates an instantiation of this entry to the given module. Returns null if this entry cannot be instantiated because it is not connected to this module.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited