InspectEntryModuleConnection class

Connects an inspect entry to a module in which it is defined or imported.

Annotations
  • @immutable

Constructors

InspectEntryModuleConnection({required String name, required String sanitizedName, required Module parentModule})
Creates a new instance of InspectEntryModuleConnection.

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
The mane of this entry in the parent module.
final
parentModule → Module
The parent module.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
The sanitized name of this entry in the parent module.
final

Methods

debugDump({InspectionCache? cache, bool expandChildren = true}) → Map<String, Object?>
Emits a JSON representation of this connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override