InstantiatedClassDefinition class final

Instantiated version of a ClassDefinition. This pins the class to a specific module.

Inheritance
  • Object
  • PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>
  • PythonObject
  • PythonClassDefinition
  • InstantiatedClassDefinition
Implemented types
Mixed-in types

Constructors

InstantiatedClassDefinition.from(ClassDefinition source, {required String name, required String sanitizedName, required InstantiatedModule instantiatingModule})
Creates a new instance of InstantiatedClassDefinition.

Properties

finalizer → Finalizer<(PythonFfiDelegate<Object?>, Object?)>
The finalizer for the python object. Gets invoked when the object is no longer accessible to the program.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initializer → Initializer<PythonFfiDelegate<Object?>, Object?>
The initializer for the python object. Gets invoked at the start of the constructor.
finalinherited
inspectModule → inspect
Returns a Dart instance of the Python inspect module.
finalinherited
instantiatingModule → InstantiatedModule
Returns the instantiating module.
final
name → String
Returns the name of this entry in the instantiating module.
final
platform → PythonFfiDelegate<Object?>
Gets the platform that this object is associated with.
no setterinherited
reference → Object?
Gets the reference to the python object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry in the instantiating module.
final
source → ClassDefinition
Returns the source entry of this instantiation.
final

Methods

call<T extends Object?>(List<Object?> args, {Map<String, Object?>? kwargs}) → T
Instantiates a new PythonClass from this class definition.
inherited
debugDump() → void
Dumps the python object to the console.
inherited
emit(StringBuffer buffer, {required InspectionCache cache, required AppType appType, String moduleParentPrefix = ""}) → void
Emits a Dart source for this entry during interface generation.
override
emitDoc(StringBuffer buffer) → void
Emits the Python documentation for this entry.
inherited
emitSource(StringBuffer buffer) → void
Emits the Python source for this entry.
inherited
getAttribute<T extends Object?>(String attributeName) → T
Gets the attribute with the given name.
inherited
getAttributeOrNull<T extends Object?>(String attributeName) → T?
Gets the attribute with the given name or null if it does not exist.
inherited
getAttributeRaw<T extends PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>>(String attributeName) → T
Gets the attribute with the given name.
inherited
getFunction(String name) → PythonFunctionInterface<PythonFfiDelegate<Object?>, Object?>
Gets the function with the given name.
inherited
hasAttribute(String attributeName) → bool
Checks if the python object has the given attribute.
inherited
newInstance(List<Object?> args, [Map<String, Object?>? kwargs]) → PythonClassInterface<PythonFfiDelegate<Object?>, Object?>
Instantiates a new PythonClass from this class definition.
inherited
noSuchMethod(Invocation invocation) → Object?
Invoked when a nonexistent method or property is accessed.
inherited
rawCall({List<Object?>? args, Map<String, Object?>? kwargs}) → Object?
Instantiates a new PythonClass from this class definition.
inherited
setAttribute<T extends Object?>(String attributeName, T value) → void
Sets the attribute with the given name.
inherited
setAttributeRaw<T extends PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>>(String attributeName, T value) → void
Sets the attribute with the given name.
inherited
toDartObject() → Object?
Converts the python object to a Dart object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited