InstantiatedInspectEntry class sealed

Base class for instantiated inspect entries.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
instantiatingModule → InstantiatedModule
Returns the instantiating module.
no setter
name → String
Returns the name of this entry in the instantiating module.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry in the instantiating module.
no setter
source → InspectEntry
Returns the source entry of this instantiation.
no setter

Methods

emit(StringBuffer buffer, {required InspectionCache cache, required AppType appType}) → void
Emits a Dart source for this entry during interface generation.
emitDoc(StringBuffer buffer) → void
Emits the Python documentation for this entry.
emitSource(StringBuffer buffer) → void
Emits the Python source for this entry.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited