ObjInfo class

Holds information about an inspected object.

Constructors

ObjInfo(PythonObjectInterface<PythonFfiDelegate<Object?>, Object?>? source)
Creates a new instance of ObjInfo from a Python object.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
module → String?
Returns the module in which the object is initially defined. This is usually the value of the Python object's __module__ attribute.
final
name → String?
Returns the name of the object. This is usually the value of the Python object's __name__ attribute.
final
qualname → String?
Returns the qualified name of the object. This is usually the value of the Python object's __qualname__ attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? qualname, String? module}) → ObjInfo
Copies this instance with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited