Primitive class final

Representation of a primitive value. This is a value that is not an instance of PythonObject, but directly mapped to a Dart type.

Implemented types
Implementers

Constructors

Primitive(String name, String sanitizedName, Object? value)
Wraps a Python object in a Primitive.
const

Properties

cachedInstantiations → Iterable<InstantiatedInspectEntry>
Returns all instantiations of this entry already created.
no setteroverride
children → Iterable<(String, InspectEntry)>
Returns all children of this entry.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
instantiatingModule → InstantiatedModule
Returns the instantiating module.
no setteroverride
moduleConnections → List<InspectEntryModuleConnection>
Returns all modules to which this entry is connected.
no setteroverride
name → String
Returns the name of this entry in the instantiating module.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName → String
Returns the sanitized name of this entry.
final
source → InspectEntry
Returns the source entry of this instantiation.
no setteroverride
type → InspectEntryType
Returns the type of this entry.
no setteroverride
value → Object?
Returns the value of this entry.
final

Methods

addModuleConnection(InspectEntryModuleConnection connection) → bool
Connects this entry to a module. Returns true if the connection was successful, false if the connection already existed.
override
collectChildren(InspectionCache cache, {required String stdlibPath, required Module parentModule}) → void
Collects all children of this entry during the inspection process.
override
debugDump({InspectionCache? cache, bool expandChildren = true}) → Map<String, Object?>
Emits a JSON representation of this entry.
override
emit(StringBuffer buffer, {required InspectionCache cache, required AppType appType}) → void
Emits a Dart source for this entry during interface generation.
override
emitDoc(StringBuffer buffer) → void
Emits the Python documentation for this entry.
override
emitSource(StringBuffer buffer) → void
Emits the Python source for this entry.
override
hasModuleConnection(InspectEntryModuleConnection connection) → bool
Helper to check if this entry has a connection to a module.
override
instantiate(InstantiatedModule instantiatingModule) → InstantiatedInspectEntry
Creates an instantiation of this entry to the given module. Returns null if this entry cannot be instantiated because it is not connected to this module.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited